@@ -1,9 +1,16 @@
-/* usaxsc.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
 /* Table of constant values */
 
@@ -13,56 +20,50 @@ static integer c__2 = 2;
 /* ----------------------------------------------------------------------- */
 /*     USPACK AXIS (AUTO SCALING)                      S.Sakai  99/10/07 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int usaxsc_(char *cside, ftnlen cside_len)
 {
     /* System generated locals */
     address a__1[2];
     integer i__1, i__2[2];
-    real r__1, r__2;
 
     /* Builtin functions */
     integer s_cmp(char *, char *, ftnlen, ftnlen);
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
     /* Local variables */
+    static integer i__;
+    static char cp[8], cs[1];
+    static integer it, ncs;
+    static real dxl, dyl;
+    static integer itr;
+    static real dxt, dyt;
     static integer mode;
     static logical loff;
     static integer nlbl;
     extern integer lenz_(char *, ftnlen);
-    static integer i__;
     static real xfact, yfact;
     static integer irota;
     static real uxmin, vxmin, vymin, vxmax, vymax, uxmax, uymin, uymax, 
-	    uxmin0, uymin0, uxmax0;
-    static char cp[8];
-    static real uymax0;
-    static char cs[1];
+	    uxmin0, uymin0, uxmax0, uymax0;
     static logical lmatch;
     extern /* Subroutine */ int msgdmp_(char *, char *, char *, ftnlen, 
-	    ftnlen, ftnlen);
+	    ftnlen, ftnlen), uliget_(char *, integer *, ftnlen);
     static integer nticks;
     extern /* Subroutine */ int cupper_(char *, ftnlen), usiget_(char *, 
 	    integer *, ftnlen), sgqwnd_(real *, real *, real *, real *), 
-	    uslget_(char *, logical *, ftnlen), uziget_(char *, integer *, 
-	    ftnlen), usrget_(char *, real *, ftnlen), uzlget_(char *, logical 
-	    *, ftnlen), ulxlog_(char *, integer *, integer *, ftnlen), 
-	    ulylog_(char *, integer *, integer *, ftnlen), sgqtrn_(integer *),
-	     uxaxdv_(char *, real *, real *, ftnlen), uzrget_(char *, real *, 
-	    ftnlen), ususcl_(char *, real *, real *, real *, real *, ftnlen), 
-	    uyaxdv_(char *, real *, real *, ftnlen), sgqvpt_(real *, real *, 
-	    real *, real *), uzlset_(char *, logical *, ftnlen), ususcu_(char 
-	    *, real *, real *, real *, real *, integer *, ftnlen), usxinz_(
-	    char *, real *, real *, ftnlen), usyinz_(char *, real *, real *, 
-	    ftnlen), usxtlz_(void);
-    static real fac;
-    extern /* Subroutine */ int usytlz_(void);
-    static real off;
-    static integer ncs;
-    static real dxl, dyl;
-    static integer itr;
-    static real dxt, dyt, xoffset, yoffset;
+	    uslget_(char *, logical *, ftnlen), uliset_(char *, integer *, 
+	    ftnlen), uziget_(char *, integer *, ftnlen), usaxlg_(char *, 
+	    integer *, integer *, ftnlen), usrget_(char *, real *, ftnlen), 
+	    uzlget_(char *, logical *, ftnlen), usaxdv_(char *, real *, real *
+	    , ftnlen), sgqtrn_(integer *), ususcl_(char *, real *, real *, 
+	    real *, real *, ftnlen), uzrget_(char *, real *, ftnlen);
+    static integer itypex, itypey;
+    extern /* Subroutine */ int sgqvpt_(real *, real *, real *, real *), 
+	    uzlset_(char *, logical *, ftnlen), ususcu_(char *, real *, real *
+	    , real *, real *, integer *, ftnlen);
+    static real xoffset, yoffset;
 
     if (s_cmp(cside, " ", cside_len, (ftnlen)1) == 0) {
 	return 0;
@@ -103,20 +104,21 @@ static integer c__2 = 2;
 		}
 		ususcu_("X", &uxmin, &uxmax, &vxmin, &vxmax, &mode, (ftnlen)1)
 			;
-		usxinz_(cs, &fac, &off, (ftnlen)1);
 		usrget_("DXT", &dxt, (ftnlen)3);
 		usrget_("DXL", &dxl, (ftnlen)3);
-		r__1 = dxt / fac;
-		r__2 = dxl / fac;
-		uxaxdv_(cs, &r__1, &r__2, (ftnlen)1);
-		usxtlz_();
+		if (*(unsigned char *)cs == 'U') {
+		    *(unsigned char *)cs = 'H';
+		}
+		usaxdv_(cs, &dxt, &dxl, (ftnlen)1);
 	    } else if (itr == 3 || itr == 4) {
 		ususcl_("X", &uxmin, &uxmax, &vxmin, &vxmax, (ftnlen)1);
-		usxinz_(cs, &fac, &off, (ftnlen)1);
 		usiget_("NLBLX", &nlbl, (ftnlen)5);
 		usiget_("NTICKSX", &nticks, (ftnlen)7);
-		ulxlog_(cs, &nlbl, &nticks, (ftnlen)1);
-		usxtlz_();
+		usiget_("ITYPEX", &itypex, (ftnlen)6);
+		uliget_("IXTYPE", &it, (ftnlen)6);
+		uliset_("IXTYPE", &itypex, (ftnlen)6);
+		usaxlg_(cs, &nlbl, &nticks, (ftnlen)1);
+		uliset_("IXTYPE", &it, (ftnlen)6);
 	    } else {
 		msgdmp_("E", "USXAXS", "INVALID TRANSFORMATION NUMBER.", (
 			ftnlen)1, (ftnlen)6, (ftnlen)30);
@@ -139,20 +141,21 @@ static integer c__2 = 2;
 		}
 		ususcu_("Y", &uymin, &uymax, &vymin, &vymax, &mode, (ftnlen)1)
 			;
-		usyinz_(cs, &fac, &off, (ftnlen)1);
 		usrget_("DYT", &dyt, (ftnlen)3);
 		usrget_("DYL", &dyl, (ftnlen)3);
-		r__1 = dyt / fac;
-		r__2 = dyl / fac;
-		uyaxdv_(cs, &r__1, &r__2, (ftnlen)1);
-		usytlz_();
+		if (*(unsigned char *)cs == 'U') {
+		    *(unsigned char *)cs = 'V';
+		}
+		usaxdv_(cs, &dyt, &dyl, (ftnlen)1);
 	    } else if (itr == 2 || itr == 4) {
 		ususcl_("Y", &uymin, &uymax, &vymin, &vymax, (ftnlen)1);
-		usyinz_(cs, &fac, &off, (ftnlen)1);
 		usiget_("NLBLY", &nlbl, (ftnlen)5);
 		usiget_("NTICKSY", &nticks, (ftnlen)7);
-		ulylog_(cs, &nlbl, &nticks, (ftnlen)1);
-		usytlz_();
+		usiget_("ITYPEY", &itypey, (ftnlen)6);
+		uliget_("IYTYPE", &it, (ftnlen)6);
+		uliset_("IYTYPE", &itypey, (ftnlen)6);
+		usaxlg_(cs, &nlbl, &nticks, (ftnlen)1);
+		uliset_("IYTYPE", &it, (ftnlen)6);
 	    } else {
 		msgdmp_("E", "USYAXS", "INVALID TRANSFORMATION NUMBER.", (
 			ftnlen)1, (ftnlen)6, (ftnlen)30);
