@@ -1,11 +1,19 @@
-/* Copyright (C) by GFD-Dennou Club, 1999-2000.  All rights reserved. */
-/* vrfct1.f -- translated by f2c (version 19990503).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
-#include "f2c.h"
+#include "libtinyf2c.h"
 
+/* ----------------------------------------------------------------------- */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int vrfct1_(real *rx, real *ry, integer *n, integer *jx, 
 	integer *jy, real *rr)
@@ -14,9 +22,8 @@
     integer i__1;
 
     /* Local variables */
-    static integer j;
+    static integer j, kx, ky;
     static real rmiss;
-    static integer kx, ky;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
 
     /* Parameter adjustments */
